import { z } from "zod";
export declare const schemaRawTransaction: z.ZodDiscriminatedUnion<"family", [z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"algorand">;
    mode: z.ZodEnum<["send", "optIn", "claimReward", "optOut"]>;
    fees: z.ZodOptional<z.ZodString>;
    assetId: z.ZodOptional<z.ZodString>;
    memo: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "algorand";
    amount: string;
    recipient: string;
    mode: "send" | "optIn" | "claimReward" | "optOut";
    fees?: string | undefined;
    assetId?: string | undefined;
    memo?: string | undefined;
}, {
    family: "algorand";
    amount: string;
    recipient: string;
    mode: "send" | "optIn" | "claimReward" | "optOut";
    fees?: string | undefined;
    assetId?: string | undefined;
    memo?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"aptos">;
    mode: z.ZodEnum<["send"]>;
    fees: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "aptos";
    amount: string;
    recipient: string;
    mode: "send";
    fees?: string | undefined;
}, {
    family: "aptos";
    amount: string;
    recipient: string;
    mode: "send";
    fees?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"bitcoin">;
    feePerByte: z.ZodOptional<z.ZodString>;
    opReturnDataHex: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "bitcoin";
    amount: string;
    recipient: string;
    feePerByte?: string | undefined;
    opReturnDataHex?: string | undefined;
}, {
    family: "bitcoin";
    amount: string;
    recipient: string;
    feePerByte?: string | undefined;
    opReturnDataHex?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"celo">;
    fees: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    mode: z.ZodEnum<["send", "lock", "unlock", "withdraw", "vote", "revoke", "activate", "register"]>;
    index: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
}, "strip", z.ZodTypeAny, {
    family: "celo";
    amount: string;
    recipient: string;
    mode: "send" | "lock" | "unlock" | "withdraw" | "vote" | "revoke" | "activate" | "register";
    fees?: string | null | undefined;
    index?: number | null | undefined;
}, {
    family: "celo";
    amount: string;
    recipient: string;
    mode: "send" | "lock" | "unlock" | "withdraw" | "vote" | "revoke" | "activate" | "register";
    fees?: string | null | undefined;
    index?: number | null | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"cosmos">;
    mode: z.ZodEnum<["send", "delegate", "undelegate", "redelegate", "claimReward", "claimRewardCompound"]>;
    fees: z.ZodOptional<z.ZodString>;
    gas: z.ZodOptional<z.ZodString>;
    memo: z.ZodOptional<z.ZodString>;
    sourceValidator: z.ZodOptional<z.ZodString>;
    validators: z.ZodOptional<z.ZodArray<z.ZodObject<{
        address: z.ZodString;
        amount: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        address: string;
        amount: string;
    }, {
        address: string;
        amount: string;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    family: "cosmos";
    amount: string;
    recipient: string;
    mode: "send" | "claimReward" | "delegate" | "undelegate" | "redelegate" | "claimRewardCompound";
    fees?: string | undefined;
    gas?: string | undefined;
    memo?: string | undefined;
    sourceValidator?: string | undefined;
    validators?: {
        address: string;
        amount: string;
    }[] | undefined;
}, {
    family: "cosmos";
    amount: string;
    recipient: string;
    mode: "send" | "claimReward" | "delegate" | "undelegate" | "redelegate" | "claimRewardCompound";
    fees?: string | undefined;
    gas?: string | undefined;
    memo?: string | undefined;
    sourceValidator?: string | undefined;
    validators?: {
        address: string;
        amount: string;
    }[] | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"crypto_org">;
    mode: z.ZodString;
    fees: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "crypto_org";
    amount: string;
    recipient: string;
    mode: string;
    fees?: string | undefined;
}, {
    family: "crypto_org";
    amount: string;
    recipient: string;
    mode: string;
    fees?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"ethereum">;
    nonce: z.ZodOptional<z.ZodNumber>;
    data: z.ZodOptional<z.ZodString>;
    gasPrice: z.ZodOptional<z.ZodString>;
    gasLimit: z.ZodOptional<z.ZodString>;
    maxPriorityFeePerGas: z.ZodOptional<z.ZodString>;
    maxFeePerGas: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "ethereum";
    amount: string;
    recipient: string;
    nonce?: number | undefined;
    data?: string | undefined;
    gasPrice?: string | undefined;
    gasLimit?: string | undefined;
    maxPriorityFeePerGas?: string | undefined;
    maxFeePerGas?: string | undefined;
}, {
    family: "ethereum";
    amount: string;
    recipient: string;
    nonce?: number | undefined;
    data?: string | undefined;
    gasPrice?: string | undefined;
    gasLimit?: string | undefined;
    maxPriorityFeePerGas?: string | undefined;
    maxFeePerGas?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"hedera">;
    memo: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "hedera";
    amount: string;
    recipient: string;
    memo?: string | undefined;
}, {
    family: "hedera";
    amount: string;
    recipient: string;
    memo?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    data: z.ZodOptional<z.ZodString>;
    family: z.ZodLiteral<"filecoin">;
    gasLimit: z.ZodNumber;
    gasFeeCap: z.ZodString;
    gasPremium: z.ZodString;
    method: z.ZodNumber;
    nonce: z.ZodNumber;
    params: z.ZodOptional<z.ZodString>;
    version: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    method: number;
    nonce: number;
    family: "filecoin";
    amount: string;
    recipient: string;
    gasLimit: number;
    gasFeeCap: string;
    gasPremium: string;
    version: number;
    data?: string | undefined;
    params?: string | undefined;
}, {
    method: number;
    nonce: number;
    family: "filecoin";
    amount: string;
    recipient: string;
    gasLimit: number;
    gasFeeCap: string;
    gasPremium: string;
    version: number;
    data?: string | undefined;
    params?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"near">;
    mode: z.ZodString;
    fees: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "near";
    amount: string;
    recipient: string;
    mode: string;
    fees?: string | undefined;
}, {
    family: "near";
    amount: string;
    recipient: string;
    mode: string;
    fees?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"neo">;
}, "strip", z.ZodTypeAny, {
    family: "neo";
    amount: string;
    recipient: string;
}, {
    family: "neo";
    amount: string;
    recipient: string;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"polkadot">;
    mode: z.ZodEnum<["send", "bond", "unbond", "rebond", "withdrawUnbonded", "setController", "nominate", "chill", "claimReward"]>;
    fee: z.ZodOptional<z.ZodString>;
    era: z.ZodOptional<z.ZodNumber>;
    validators: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    rewardDestination: z.ZodOptional<z.ZodEnum<["Staked", "Stash", "Controller", "Account", "None"]>>;
    numOfSlashingSpans: z.ZodOptional<z.ZodNumber>;
}, "strip", z.ZodTypeAny, {
    family: "polkadot";
    amount: string;
    recipient: string;
    mode: "send" | "claimReward" | "bond" | "unbond" | "rebond" | "withdrawUnbonded" | "setController" | "nominate" | "chill";
    fee?: string | undefined;
    era?: number | undefined;
    validators?: string[] | undefined;
    rewardDestination?: "None" | "Staked" | "Stash" | "Controller" | "Account" | undefined;
    numOfSlashingSpans?: number | undefined;
}, {
    family: "polkadot";
    amount: string;
    recipient: string;
    mode: "send" | "claimReward" | "bond" | "unbond" | "rebond" | "withdrawUnbonded" | "setController" | "nominate" | "chill";
    fee?: string | undefined;
    era?: number | undefined;
    validators?: string[] | undefined;
    rewardDestination?: "None" | "Staked" | "Stash" | "Controller" | "Account" | undefined;
    numOfSlashingSpans?: number | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"ripple">;
    fee: z.ZodOptional<z.ZodString>;
    tag: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    family: "ripple";
    amount: string;
    recipient: string;
    tag: number;
    fee?: string | undefined;
}, {
    family: "ripple";
    amount: string;
    recipient: string;
    tag: number;
    fee?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"stellar">;
    fees: z.ZodOptional<z.ZodString>;
    memoType: z.ZodOptional<z.ZodEnum<["MEMO_TEXT", "MEMO_ID", "MEMO_HASH", "MEMO_RETURN"]>>;
    memoValue: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "stellar";
    amount: string;
    recipient: string;
    fees?: string | undefined;
    memoType?: "MEMO_TEXT" | "MEMO_ID" | "MEMO_HASH" | "MEMO_RETURN" | undefined;
    memoValue?: string | undefined;
}, {
    family: "stellar";
    amount: string;
    recipient: string;
    fees?: string | undefined;
    memoType?: "MEMO_TEXT" | "MEMO_ID" | "MEMO_HASH" | "MEMO_RETURN" | undefined;
    memoValue?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"tezos">;
    mode: z.ZodEnum<["send", "delegate", "undelegate"]>;
    fees: z.ZodOptional<z.ZodString>;
    gasLimit: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "tezos";
    amount: string;
    recipient: string;
    mode: "send" | "delegate" | "undelegate";
    fees?: string | undefined;
    gasLimit?: string | undefined;
}, {
    family: "tezos";
    amount: string;
    recipient: string;
    mode: "send" | "delegate" | "undelegate";
    fees?: string | undefined;
    gasLimit?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"ton">;
    fees: z.ZodString;
    comment: z.ZodObject<{
        isEncrypted: z.ZodBoolean;
        text: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        text: string;
        isEncrypted: boolean;
    }, {
        text: string;
        isEncrypted: boolean;
    }>;
    payload: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
        type: z.ZodLiteral<"comment">;
        text: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "comment";
        text: string;
    }, {
        type: "comment";
        text: string;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"jetton-transfer">;
        queryId: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        amount: z.ZodString;
        destination: z.ZodString;
        responseDestination: z.ZodString;
        customPayload: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        forwardAmount: z.ZodString;
        forwardPayload: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        knownJetton: z.ZodUnion<[z.ZodObject<{
            jettonId: z.ZodNumber;
            workchain: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            jettonId: number;
            workchain: number;
        }, {
            jettonId: number;
            workchain: number;
        }>, z.ZodNull]>;
    }, "strip", z.ZodTypeAny, {
        type: "jetton-transfer";
        amount: string;
        queryId: string | null;
        destination: string;
        responseDestination: string;
        customPayload: string | null;
        forwardAmount: string;
        forwardPayload: string | null;
        knownJetton: {
            jettonId: number;
            workchain: number;
        } | null;
    }, {
        type: "jetton-transfer";
        amount: string;
        queryId: string | null;
        destination: string;
        responseDestination: string;
        customPayload: string | null;
        forwardAmount: string;
        forwardPayload: string | null;
        knownJetton: {
            jettonId: number;
            workchain: number;
        } | null;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"nft-transfer">;
        queryId: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        newOwner: z.ZodString;
        responseDestination: z.ZodString;
        customPayload: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        forwardAmount: z.ZodString;
        forwardPayload: z.ZodUnion<[z.ZodString, z.ZodNull]>;
    }, "strip", z.ZodTypeAny, {
        type: "nft-transfer";
        queryId: string | null;
        responseDestination: string;
        customPayload: string | null;
        forwardAmount: string;
        forwardPayload: string | null;
        newOwner: string;
    }, {
        type: "nft-transfer";
        queryId: string | null;
        responseDestination: string;
        customPayload: string | null;
        forwardAmount: string;
        forwardPayload: string | null;
        newOwner: string;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"unsafe">;
        message: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "unsafe";
        message: string;
    }, {
        type: "unsafe";
        message: string;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"jetton-burn">;
        queryId: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        amount: z.ZodString;
        responseDestination: z.ZodString;
        customPayload: z.ZodUnion<[z.ZodString, z.ZodNull]>;
    }, "strip", z.ZodTypeAny, {
        type: "jetton-burn";
        amount: string;
        queryId: string | null;
        responseDestination: string;
        customPayload: string | null;
    }, {
        type: "jetton-burn";
        amount: string;
        queryId: string | null;
        responseDestination: string;
        customPayload: string | null;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"add-whitelist">;
        queryId: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        address: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "add-whitelist";
        address: string;
        queryId: string | null;
    }, {
        type: "add-whitelist";
        address: string;
        queryId: string | null;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"single-nominator-withdraw">;
        queryId: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        amount: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "single-nominator-withdraw";
        amount: string;
        queryId: string | null;
    }, {
        type: "single-nominator-withdraw";
        amount: string;
        queryId: string | null;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"single-nominator-change-validator">;
        queryId: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        address: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "single-nominator-change-validator";
        address: string;
        queryId: string | null;
    }, {
        type: "single-nominator-change-validator";
        address: string;
        queryId: string | null;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"tonstakers-deposit">;
        queryId: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        appId: z.ZodUnion<[z.ZodString, z.ZodNull]>;
    }, "strip", z.ZodTypeAny, {
        type: "tonstakers-deposit";
        queryId: string | null;
        appId: string | null;
    }, {
        type: "tonstakers-deposit";
        queryId: string | null;
        appId: string | null;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"vote-for-proposal">;
        queryId: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        votingAddress: z.ZodString;
        expirationDate: z.ZodNumber;
        vote: z.ZodBoolean;
        needConfirmation: z.ZodBoolean;
    }, "strip", z.ZodTypeAny, {
        type: "vote-for-proposal";
        vote: boolean;
        queryId: string | null;
        votingAddress: string;
        expirationDate: number;
        needConfirmation: boolean;
    }, {
        type: "vote-for-proposal";
        vote: boolean;
        queryId: string | null;
        votingAddress: string;
        expirationDate: number;
        needConfirmation: boolean;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"change-dns-record">;
        queryId: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        record: z.ZodUnion<[z.ZodObject<{
            type: z.ZodLiteral<"wallet">;
            value: z.ZodUnion<[z.ZodObject<{
                address: z.ZodString;
                capabilities: z.ZodUnion<[z.ZodObject<{
                    isWallet: z.ZodBoolean;
                }, "strip", z.ZodTypeAny, {
                    isWallet: boolean;
                }, {
                    isWallet: boolean;
                }>, z.ZodNull]>;
            }, "strip", z.ZodTypeAny, {
                address: string;
                capabilities: {
                    isWallet: boolean;
                } | null;
            }, {
                address: string;
                capabilities: {
                    isWallet: boolean;
                } | null;
            }>, z.ZodNull]>;
        }, "strip", z.ZodTypeAny, {
            type: "wallet";
            value: {
                address: string;
                capabilities: {
                    isWallet: boolean;
                } | null;
            } | null;
        }, {
            type: "wallet";
            value: {
                address: string;
                capabilities: {
                    isWallet: boolean;
                } | null;
            } | null;
        }>, z.ZodObject<{
            type: z.ZodLiteral<"unknown">;
            key: z.ZodString;
            value: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        }, "strip", z.ZodTypeAny, {
            type: "unknown";
            key: string;
            value: string | null;
        }, {
            type: "unknown";
            key: string;
            value: string | null;
        }>]>;
    }, "strip", z.ZodTypeAny, {
        type: "change-dns-record";
        record: {
            type: "wallet";
            value: {
                address: string;
                capabilities: {
                    isWallet: boolean;
                } | null;
            } | null;
        } | {
            type: "unknown";
            key: string;
            value: string | null;
        };
        queryId: string | null;
    }, {
        type: "change-dns-record";
        record: {
            type: "wallet";
            value: {
                address: string;
                capabilities: {
                    isWallet: boolean;
                } | null;
            } | null;
        } | {
            type: "unknown";
            key: string;
            value: string | null;
        };
        queryId: string | null;
    }>, z.ZodObject<{
        type: z.ZodLiteral<"token-bridge-pay-swap">;
        queryId: z.ZodUnion<[z.ZodString, z.ZodNull]>;
        swapId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "token-bridge-pay-swap";
        queryId: string | null;
        swapId: string;
    }, {
        type: "token-bridge-pay-swap";
        queryId: string | null;
        swapId: string;
    }>]>>;
}, "strip", z.ZodTypeAny, {
    family: "ton";
    amount: string;
    recipient: string;
    fees: string;
    comment: {
        text: string;
        isEncrypted: boolean;
    };
    payload?: {
        type: "jetton-transfer";
        amount: string;
        queryId: string | null;
        destination: string;
        responseDestination: string;
        customPayload: string | null;
        forwardAmount: string;
        forwardPayload: string | null;
        knownJetton: {
            jettonId: number;
            workchain: number;
        } | null;
    } | {
        type: "nft-transfer";
        queryId: string | null;
        responseDestination: string;
        customPayload: string | null;
        forwardAmount: string;
        forwardPayload: string | null;
        newOwner: string;
    } | {
        type: "comment";
        text: string;
    } | {
        type: "unsafe";
        message: string;
    } | {
        type: "jetton-burn";
        amount: string;
        queryId: string | null;
        responseDestination: string;
        customPayload: string | null;
    } | {
        type: "add-whitelist";
        address: string;
        queryId: string | null;
    } | {
        type: "single-nominator-withdraw";
        amount: string;
        queryId: string | null;
    } | {
        type: "single-nominator-change-validator";
        address: string;
        queryId: string | null;
    } | {
        type: "tonstakers-deposit";
        queryId: string | null;
        appId: string | null;
    } | {
        type: "vote-for-proposal";
        vote: boolean;
        queryId: string | null;
        votingAddress: string;
        expirationDate: number;
        needConfirmation: boolean;
    } | {
        type: "change-dns-record";
        record: {
            type: "wallet";
            value: {
                address: string;
                capabilities: {
                    isWallet: boolean;
                } | null;
            } | null;
        } | {
            type: "unknown";
            key: string;
            value: string | null;
        };
        queryId: string | null;
    } | {
        type: "token-bridge-pay-swap";
        queryId: string | null;
        swapId: string;
    } | undefined;
}, {
    family: "ton";
    amount: string;
    recipient: string;
    fees: string;
    comment: {
        text: string;
        isEncrypted: boolean;
    };
    payload?: {
        type: "jetton-transfer";
        amount: string;
        queryId: string | null;
        destination: string;
        responseDestination: string;
        customPayload: string | null;
        forwardAmount: string;
        forwardPayload: string | null;
        knownJetton: {
            jettonId: number;
            workchain: number;
        } | null;
    } | {
        type: "nft-transfer";
        queryId: string | null;
        responseDestination: string;
        customPayload: string | null;
        forwardAmount: string;
        forwardPayload: string | null;
        newOwner: string;
    } | {
        type: "comment";
        text: string;
    } | {
        type: "unsafe";
        message: string;
    } | {
        type: "jetton-burn";
        amount: string;
        queryId: string | null;
        responseDestination: string;
        customPayload: string | null;
    } | {
        type: "add-whitelist";
        address: string;
        queryId: string | null;
    } | {
        type: "single-nominator-withdraw";
        amount: string;
        queryId: string | null;
    } | {
        type: "single-nominator-change-validator";
        address: string;
        queryId: string | null;
    } | {
        type: "tonstakers-deposit";
        queryId: string | null;
        appId: string | null;
    } | {
        type: "vote-for-proposal";
        vote: boolean;
        queryId: string | null;
        votingAddress: string;
        expirationDate: number;
        needConfirmation: boolean;
    } | {
        type: "change-dns-record";
        record: {
            type: "wallet";
            value: {
                address: string;
                capabilities: {
                    isWallet: boolean;
                } | null;
            } | null;
        } | {
            type: "unknown";
            key: string;
            value: string | null;
        };
        queryId: string | null;
    } | {
        type: "token-bridge-pay-swap";
        queryId: string | null;
        swapId: string;
    } | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"tron">;
    mode: z.ZodEnum<["send", "freeze", "unfreeze", "vote", "claimReward", "withdrawExpireUnfreeze", "unDelegateResource", "legacyUnfreeze"]>;
    resource: z.ZodOptional<z.ZodEnum<["BANDWIDTH", "ENERGY"]>>;
    duration: z.ZodOptional<z.ZodNumber>;
    votes: z.ZodOptional<z.ZodArray<z.ZodObject<{
        address: z.ZodString;
        voteCount: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        address: string;
        voteCount: number;
    }, {
        address: string;
        voteCount: number;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    family: "tron";
    amount: string;
    recipient: string;
    mode: "send" | "claimReward" | "vote" | "freeze" | "unfreeze" | "withdrawExpireUnfreeze" | "unDelegateResource" | "legacyUnfreeze";
    resource?: "BANDWIDTH" | "ENERGY" | undefined;
    duration?: number | undefined;
    votes?: {
        address: string;
        voteCount: number;
    }[] | undefined;
}, {
    family: "tron";
    amount: string;
    recipient: string;
    mode: "send" | "claimReward" | "vote" | "freeze" | "unfreeze" | "withdrawExpireUnfreeze" | "unDelegateResource" | "legacyUnfreeze";
    resource?: "BANDWIDTH" | "ENERGY" | undefined;
    duration?: number | undefined;
    votes?: {
        address: string;
        voteCount: number;
    }[] | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"elrond">;
    mode: z.ZodUnion<[z.ZodLiteral<"send">, z.ZodLiteral<"delegate">, z.ZodLiteral<"reDelegateRewards">, z.ZodLiteral<"unDelegate">, z.ZodLiteral<"claimRewards">, z.ZodLiteral<"withdraw">]>;
    fees: z.ZodOptional<z.ZodString>;
    data: z.ZodOptional<z.ZodString>;
    gasLimit: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    family: "elrond";
    amount: string;
    recipient: string;
    mode: "send" | "withdraw" | "delegate" | "reDelegateRewards" | "unDelegate" | "claimRewards";
    gasLimit: number;
    fees?: string | undefined;
    data?: string | undefined;
}, {
    family: "elrond";
    amount: string;
    recipient: string;
    mode: "send" | "withdraw" | "delegate" | "reDelegateRewards" | "unDelegate" | "claimRewards";
    gasLimit: number;
    fees?: string | undefined;
    data?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"cardano">;
    fees: z.ZodOptional<z.ZodString>;
    mode: z.ZodString;
    memo: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "cardano";
    amount: string;
    recipient: string;
    mode: string;
    fees?: string | undefined;
    memo?: string | undefined;
}, {
    family: "cardano";
    amount: string;
    recipient: string;
    mode: string;
    fees?: string | undefined;
    memo?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"solana">;
    model: z.ZodString;
    raw: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "solana";
    amount: string;
    recipient: string;
    model: string;
    raw?: string | undefined;
}, {
    family: "solana";
    amount: string;
    recipient: string;
    model: string;
    raw?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"vechain">;
    estimatedFees: z.ZodString;
    body: z.ZodObject<{
        chainTag: z.ZodNumber;
        blockRef: z.ZodString;
        expiration: z.ZodNumber;
        clauses: z.ZodArray<z.ZodObject<{
            to: z.ZodNullable<z.ZodString>;
            value: z.ZodUnion<[z.ZodString, z.ZodNumber]>;
            data: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            data: string;
            value: string | number;
            to: string | null;
        }, {
            data: string;
            value: string | number;
            to: string | null;
        }>, "many">;
        gasPriceCoef: z.ZodNumber;
        gas: z.ZodUnion<[z.ZodString, z.ZodNumber]>;
        dependsOn: z.ZodNullable<z.ZodString>;
        nonce: z.ZodUnion<[z.ZodString, z.ZodNumber]>;
        reserved: z.ZodOptional<z.ZodObject<{
            features: z.ZodOptional<z.ZodNumber>;
            unused: z.ZodOptional<z.ZodArray<z.ZodAny, "many">>;
        }, "strip", z.ZodTypeAny, {
            features?: number | undefined;
            unused?: any[] | undefined;
        }, {
            features?: number | undefined;
            unused?: any[] | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        nonce: string | number;
        gas: string | number;
        chainTag: number;
        blockRef: string;
        expiration: number;
        clauses: {
            data: string;
            value: string | number;
            to: string | null;
        }[];
        gasPriceCoef: number;
        dependsOn: string | null;
        reserved?: {
            features?: number | undefined;
            unused?: any[] | undefined;
        } | undefined;
    }, {
        nonce: string | number;
        gas: string | number;
        chainTag: number;
        blockRef: string;
        expiration: number;
        clauses: {
            data: string;
            value: string | number;
            to: string | null;
        }[];
        gasPriceCoef: number;
        dependsOn: string | null;
        reserved?: {
            features?: number | undefined;
            unused?: any[] | undefined;
        } | undefined;
    }>;
}, "strip", z.ZodTypeAny, {
    body: {
        nonce: string | number;
        gas: string | number;
        chainTag: number;
        blockRef: string;
        expiration: number;
        clauses: {
            data: string;
            value: string | number;
            to: string | null;
        }[];
        gasPriceCoef: number;
        dependsOn: string | null;
        reserved?: {
            features?: number | undefined;
            unused?: any[] | undefined;
        } | undefined;
    };
    family: "vechain";
    amount: string;
    recipient: string;
    estimatedFees: string;
}, {
    body: {
        nonce: string | number;
        gas: string | number;
        chainTag: number;
        blockRef: string;
        expiration: number;
        clauses: {
            data: string;
            value: string | number;
            to: string | null;
        }[];
        gasPriceCoef: number;
        dependsOn: string | null;
        reserved?: {
            features?: number | undefined;
            unused?: any[] | undefined;
        } | undefined;
    };
    family: "vechain";
    amount: string;
    recipient: string;
    estimatedFees: string;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"stacks">;
    fee: z.ZodOptional<z.ZodString>;
    nonce: z.ZodOptional<z.ZodString>;
    memo: z.ZodOptional<z.ZodString>;
    network: z.ZodString;
    anchorMode: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    network: string;
    family: "stacks";
    amount: string;
    recipient: string;
    anchorMode: number;
    fee?: string | undefined;
    nonce?: string | undefined;
    memo?: string | undefined;
}, {
    network: string;
    family: "stacks";
    amount: string;
    recipient: string;
    anchorMode: number;
    fee?: string | undefined;
    nonce?: string | undefined;
    memo?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"internet_computer">;
    fees: z.ZodString;
    memo: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "internet_computer";
    amount: string;
    recipient: string;
    fees: string;
    memo?: string | undefined;
}, {
    family: "internet_computer";
    amount: string;
    recipient: string;
    fees: string;
    memo?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"casper">;
    fees: z.ZodString;
    transferId: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "casper";
    amount: string;
    recipient: string;
    fees: string;
    transferId?: string | undefined;
}, {
    family: "casper";
    amount: string;
    recipient: string;
    fees: string;
    transferId?: string | undefined;
}>, z.ZodObject<{
    amount: z.ZodString;
    recipient: z.ZodString;
    family: z.ZodLiteral<"sui">;
    mode: z.ZodString;
    fees: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    family: "sui";
    amount: string;
    recipient: string;
    mode: string;
    fees?: string | undefined;
}, {
    family: "sui";
    amount: string;
    recipient: string;
    mode: string;
    fees?: string | undefined;
}>]>;
//# sourceMappingURL=validation.d.ts.map