"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deserializeAccount = exports.serializeAccount = void 0;
const bignumber_js_1 = __importDefault(require("bignumber.js"));
/**
 * Serialize an [[Account]] object in order to send it over JSON-RPC protocol
 * to the Ledger Live platform
 * @param account - The account object to serialize
 *
 * @returns The raw representation of the provided account object
 */
function serializeAccount({ id, name, address, currency, balance, spendableBalance, blockHeight, lastSyncDate, parentAccountId, }) {
    return {
        id,
        name,
        address,
        currency,
        balance: balance.toString(),
        spendableBalance: spendableBalance.toString(),
        blockHeight,
        lastSyncDate: lastSyncDate.toISOString(),
        parentAccountId,
    };
}
exports.serializeAccount = serializeAccount;
/**
 * Deserialize a [[RawAccount]] object after it has been received over JSON-RPC
 * protocol from the Ledger Live platform
 * @param rawAccount - The raw account representation to deserialize
 *
 * @returns The object account of the provided raw account representation
 */
function deserializeAccount({ id, name, address, currency, balance, spendableBalance, blockHeight, lastSyncDate, parentAccountId, }) {
    return {
        id,
        name,
        address,
        currency,
        balance: new bignumber_js_1.default(balance),
        spendableBalance: new bignumber_js_1.default(spendableBalance),
        blockHeight,
        lastSyncDate: new Date(lastSyncDate),
        parentAccountId,
    };
}
exports.deserializeAccount = deserializeAccount;
//# sourceMappingURL=serializers.js.map