import { z } from "zod";
export declare const schemaServerErrorCode: z.ZodEnum<["NOT_IMPLEMENTED_BY_WALLET", "ACCOUNT_NOT_FOUND", "CURRENCY_NOT_FOUND", "PERMISSION_DENIED", "UNKNOWN_ERROR", "UNAUTHORIZED_STORE"]>;
export type ServerErrorCode = z.infer<typeof schemaServerErrorCode>;
export declare const schemaNotImplementedByWallet: z.ZodObject<{
    code: z.ZodLiteral<"NOT_IMPLEMENTED_BY_WALLET">;
    message: z.ZodString;
    data: z.ZodObject<{
        methodId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        methodId: string;
    }, {
        methodId: string;
    }>;
}, "strip", z.ZodTypeAny, {
    code: "NOT_IMPLEMENTED_BY_WALLET";
    data: {
        methodId: string;
    };
    message: string;
}, {
    code: "NOT_IMPLEMENTED_BY_WALLET";
    data: {
        methodId: string;
    };
    message: string;
}>;
export type NotImplementedByWallet = z.infer<typeof schemaNotImplementedByWallet>;
export declare const schemaAccountNotFound: z.ZodObject<{
    code: z.ZodLiteral<"ACCOUNT_NOT_FOUND">;
    message: z.ZodString;
    data: z.ZodObject<{
        accountId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        accountId: string;
    }, {
        accountId: string;
    }>;
}, "strip", z.ZodTypeAny, {
    code: "ACCOUNT_NOT_FOUND";
    data: {
        accountId: string;
    };
    message: string;
}, {
    code: "ACCOUNT_NOT_FOUND";
    data: {
        accountId: string;
    };
    message: string;
}>;
export type AccountNotFound = z.infer<typeof schemaAccountNotFound>;
export declare const schemaCurrencyNotFound: z.ZodObject<{
    code: z.ZodLiteral<"CURRENCY_NOT_FOUND">;
    message: z.ZodString;
    data: z.ZodObject<{
        currencyId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        currencyId: string;
    }, {
        currencyId: string;
    }>;
}, "strip", z.ZodTypeAny, {
    code: "CURRENCY_NOT_FOUND";
    data: {
        currencyId: string;
    };
    message: string;
}, {
    code: "CURRENCY_NOT_FOUND";
    data: {
        currencyId: string;
    };
    message: string;
}>;
export type CurrencyNotFound = z.infer<typeof schemaCurrencyNotFound>;
export declare const schemaPermissionDenied: z.ZodObject<{
    code: z.ZodLiteral<"PERMISSION_DENIED">;
    message: z.ZodString;
    data: z.ZodObject<{
        methodId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        methodId: string;
    }, {
        methodId: string;
    }>;
}, "strip", z.ZodTypeAny, {
    code: "PERMISSION_DENIED";
    data: {
        methodId: string;
    };
    message: string;
}, {
    code: "PERMISSION_DENIED";
    data: {
        methodId: string;
    };
    message: string;
}>;
export type PermissionDenied = z.infer<typeof schemaPermissionDenied>;
export declare const schemaUnknownErrorData: z.ZodObject<{
    name: z.ZodOptional<z.ZodString>;
    message: z.ZodOptional<z.ZodString>;
    stack: z.ZodOptional<z.ZodString>;
    cause: z.ZodOptional<z.ZodUnknown>;
    code: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    name?: string | undefined;
    message?: string | undefined;
    stack?: string | undefined;
    cause?: unknown;
    code?: string | undefined;
}, {
    name?: string | undefined;
    message?: string | undefined;
    stack?: string | undefined;
    cause?: unknown;
    code?: string | undefined;
}>;
export type UnknownErrorData = z.infer<typeof schemaUnknownErrorData>;
export declare const schemaUnknownError: z.ZodObject<{
    code: z.ZodLiteral<"UNKNOWN_ERROR">;
    message: z.ZodString;
    data: z.ZodObject<{
        name: z.ZodOptional<z.ZodString>;
        message: z.ZodOptional<z.ZodString>;
        stack: z.ZodOptional<z.ZodString>;
        cause: z.ZodOptional<z.ZodUnknown>;
        code: z.ZodOptional<z.ZodString>;
    }, "passthrough", z.ZodTypeAny, z.objectOutputType<{
        name: z.ZodOptional<z.ZodString>;
        message: z.ZodOptional<z.ZodString>;
        stack: z.ZodOptional<z.ZodString>;
        cause: z.ZodOptional<z.ZodUnknown>;
        code: z.ZodOptional<z.ZodString>;
    }, z.ZodTypeAny, "passthrough">, z.objectInputType<{
        name: z.ZodOptional<z.ZodString>;
        message: z.ZodOptional<z.ZodString>;
        stack: z.ZodOptional<z.ZodString>;
        cause: z.ZodOptional<z.ZodUnknown>;
        code: z.ZodOptional<z.ZodString>;
    }, z.ZodTypeAny, "passthrough">>;
}, "strip", z.ZodTypeAny, {
    code: "UNKNOWN_ERROR";
    data: {
        name?: string | undefined;
        message?: string | undefined;
        stack?: string | undefined;
        cause?: unknown;
        code?: string | undefined;
    } & {
        [k: string]: unknown;
    };
    message: string;
}, {
    code: "UNKNOWN_ERROR";
    data: {
        name?: string | undefined;
        message?: string | undefined;
        stack?: string | undefined;
        cause?: unknown;
        code?: string | undefined;
    } & {
        [k: string]: unknown;
    };
    message: string;
}>;
export type UnknownError = z.infer<typeof schemaUnknownError>;
export declare const schemaUnauthorizedStore: z.ZodObject<{
    code: z.ZodLiteral<"UNAUTHORIZED_STORE">;
    message: z.ZodString;
    data: z.ZodObject<{
        storeId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        storeId: string;
    }, {
        storeId: string;
    }>;
}, "strip", z.ZodTypeAny, {
    code: "UNAUTHORIZED_STORE";
    data: {
        storeId: string;
    };
    message: string;
}, {
    code: "UNAUTHORIZED_STORE";
    data: {
        storeId: string;
    };
    message: string;
}>;
export type UnauthorizedStore = z.infer<typeof schemaUnauthorizedStore>;
export declare const schemaServerErrorData: z.ZodDiscriminatedUnion<"code", [z.ZodObject<{
    code: z.ZodLiteral<"NOT_IMPLEMENTED_BY_WALLET">;
    message: z.ZodString;
    data: z.ZodObject<{
        methodId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        methodId: string;
    }, {
        methodId: string;
    }>;
}, "strip", z.ZodTypeAny, {
    code: "NOT_IMPLEMENTED_BY_WALLET";
    data: {
        methodId: string;
    };
    message: string;
}, {
    code: "NOT_IMPLEMENTED_BY_WALLET";
    data: {
        methodId: string;
    };
    message: string;
}>, z.ZodObject<{
    code: z.ZodLiteral<"ACCOUNT_NOT_FOUND">;
    message: z.ZodString;
    data: z.ZodObject<{
        accountId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        accountId: string;
    }, {
        accountId: string;
    }>;
}, "strip", z.ZodTypeAny, {
    code: "ACCOUNT_NOT_FOUND";
    data: {
        accountId: string;
    };
    message: string;
}, {
    code: "ACCOUNT_NOT_FOUND";
    data: {
        accountId: string;
    };
    message: string;
}>, z.ZodObject<{
    code: z.ZodLiteral<"CURRENCY_NOT_FOUND">;
    message: z.ZodString;
    data: z.ZodObject<{
        currencyId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        currencyId: string;
    }, {
        currencyId: string;
    }>;
}, "strip", z.ZodTypeAny, {
    code: "CURRENCY_NOT_FOUND";
    data: {
        currencyId: string;
    };
    message: string;
}, {
    code: "CURRENCY_NOT_FOUND";
    data: {
        currencyId: string;
    };
    message: string;
}>, z.ZodObject<{
    code: z.ZodLiteral<"PERMISSION_DENIED">;
    message: z.ZodString;
    data: z.ZodObject<{
        methodId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        methodId: string;
    }, {
        methodId: string;
    }>;
}, "strip", z.ZodTypeAny, {
    code: "PERMISSION_DENIED";
    data: {
        methodId: string;
    };
    message: string;
}, {
    code: "PERMISSION_DENIED";
    data: {
        methodId: string;
    };
    message: string;
}>, z.ZodObject<{
    code: z.ZodLiteral<"UNKNOWN_ERROR">;
    message: z.ZodString;
    data: z.ZodObject<{
        name: z.ZodOptional<z.ZodString>;
        message: z.ZodOptional<z.ZodString>;
        stack: z.ZodOptional<z.ZodString>;
        cause: z.ZodOptional<z.ZodUnknown>;
        code: z.ZodOptional<z.ZodString>;
    }, "passthrough", z.ZodTypeAny, z.objectOutputType<{
        name: z.ZodOptional<z.ZodString>;
        message: z.ZodOptional<z.ZodString>;
        stack: z.ZodOptional<z.ZodString>;
        cause: z.ZodOptional<z.ZodUnknown>;
        code: z.ZodOptional<z.ZodString>;
    }, z.ZodTypeAny, "passthrough">, z.objectInputType<{
        name: z.ZodOptional<z.ZodString>;
        message: z.ZodOptional<z.ZodString>;
        stack: z.ZodOptional<z.ZodString>;
        cause: z.ZodOptional<z.ZodUnknown>;
        code: z.ZodOptional<z.ZodString>;
    }, z.ZodTypeAny, "passthrough">>;
}, "strip", z.ZodTypeAny, {
    code: "UNKNOWN_ERROR";
    data: {
        name?: string | undefined;
        message?: string | undefined;
        stack?: string | undefined;
        cause?: unknown;
        code?: string | undefined;
    } & {
        [k: string]: unknown;
    };
    message: string;
}, {
    code: "UNKNOWN_ERROR";
    data: {
        name?: string | undefined;
        message?: string | undefined;
        stack?: string | undefined;
        cause?: unknown;
        code?: string | undefined;
    } & {
        [k: string]: unknown;
    };
    message: string;
}>, z.ZodObject<{
    code: z.ZodLiteral<"UNAUTHORIZED_STORE">;
    message: z.ZodString;
    data: z.ZodObject<{
        storeId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        storeId: string;
    }, {
        storeId: string;
    }>;
}, "strip", z.ZodTypeAny, {
    code: "UNAUTHORIZED_STORE";
    data: {
        storeId: string;
    };
    message: string;
}, {
    code: "UNAUTHORIZED_STORE";
    data: {
        storeId: string;
    };
    message: string;
}>]>;
export type ServerErrorData = z.infer<typeof schemaServerErrorData>;
//# sourceMappingURL=types.d.ts.map