"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deserializeTransaction = exports.serializeTransaction = void 0;
const serializer_1 = require("./algorand/serializer");
const serializer_2 = require("./aptos/serializer");
const serializer_3 = require("./bitcoin/serializer");
const serializer_4 = require("./celo/serializer");
const serializer_5 = require("./cosmos/serializer");
const serializer_6 = require("./crypto_org/serializer");
const serializer_7 = require("./ethereum/serializer");
const near = __importStar(require("./near/serializer"));
const serializer_8 = require("./hedera/serializer");
const serializer_9 = require("./filecoin/serializer");
const neo = __importStar(require("./neo/serializer"));
const serializer_10 = require("./polkadot/serializer");
const serializer_11 = require("./ripple/serializer");
const serializer_12 = require("./stellar/serializer");
const serializer_13 = require("./tezos/serializer");
const serializer_14 = require("./ton/serializer");
const serializer_15 = require("./tron/serializer");
const serializer_16 = require("./elrond/serializer");
const serializer_17 = require("./cardano/serializer");
const serializer_18 = require("./solana/serializer");
const serializer_19 = require("./vechain/serializer");
const serializer_20 = require("./stacks/serializer");
const serializer_21 = require("./internet_computer/serializer");
const serializer_22 = require("./casper/serializer");
const serializer_23 = require("./sui/serializer");
/**
 * Serialize an [[Transaction]] object in order to send it over JSON-RPC
 * protocol to the Ledger Live platform
 * @param transaction - The transaction object to serialize
 *
 * @returns The raw representation of the provided transaction object
 */
function serializeTransaction(transaction) {
    switch (transaction.family) {
        case "ethereum":
            return (0, serializer_7.serializeEthereumTransaction)(transaction);
        case "bitcoin":
            return (0, serializer_3.serializeBitcoinTransaction)(transaction);
        case "algorand":
            return (0, serializer_1.serializeAlgorandTransaction)(transaction);
        case "aptos":
            return (0, serializer_2.serializeAptosTransaction)(transaction);
        case "crypto_org":
            return (0, serializer_6.serializeCryptoOrgTransaction)(transaction);
        case "ripple":
            return (0, serializer_11.serializeRippleTransaction)(transaction);
        case "celo":
            return (0, serializer_4.serializeCeloTransaction)(transaction);
        case "cosmos":
            return (0, serializer_5.serializeCosmosTransaction)(transaction);
        case "hedera":
            return (0, serializer_8.serializeHederaTransaction)(transaction);
        case "filecoin":
            return (0, serializer_9.serializeFilecoinTransaction)(transaction);
        case "tezos":
            return (0, serializer_13.serializeTezosTransaction)(transaction);
        case "polkadot":
            return (0, serializer_10.serializePolkadotTransaction)(transaction);
        case "stellar":
            return (0, serializer_12.serializeStellarTransaction)(transaction);
        case "ton":
            return (0, serializer_14.serializeTonTransaction)(transaction);
        case "tron":
            return (0, serializer_15.serializeTronTransaction)(transaction);
        case "near":
            return near.serialize(transaction);
        case "neo":
            return neo.serialize(transaction);
        case "elrond":
            return (0, serializer_16.serializeElrondTransaction)(transaction);
        case "cardano":
            return (0, serializer_17.serializeCardanoTransaction)(transaction);
        case "solana":
            return (0, serializer_18.serializeSolanaTransaction)(transaction);
        case "vechain":
            return (0, serializer_19.serializeVechainTransaction)(transaction);
        case "stacks":
            return (0, serializer_20.serializeStacksTransaction)(transaction);
        case "internet_computer":
            return (0, serializer_21.serializeInternetComputerTransaction)(transaction);
        case "casper":
            return (0, serializer_22.serializeCasperTransaction)(transaction);
        case "sui":
            return (0, serializer_23.serializeSuiTransaction)(transaction);
        default: {
            const exhaustiveCheck = transaction; // https://www.typescriptlang.org/docs/handbook/2/narrowing.html#exhaustiveness-checking
            return exhaustiveCheck;
            // throw new Error("Can't serialize transaction: family not supported");
        }
    }
}
exports.serializeTransaction = serializeTransaction;
/**
 * Deserialize a [[RawTransaction]] object after it has been received over
 * JSON-RPC protocol from the Ledger Live platform
 * @param rawTransaction - The raw transaction representation to deserialize
 *
 * @returns The object transaction of the provided raw transaction representation
 */
function deserializeTransaction(rawTransaction) {
    switch (rawTransaction.family) {
        case "ethereum":
            return (0, serializer_7.deserializeEthereumTransaction)(rawTransaction);
        case "bitcoin":
            return (0, serializer_3.deserializeBitcoinTransaction)(rawTransaction);
        case "algorand":
            return (0, serializer_1.deserializeAlgorandTransaction)(rawTransaction);
        case "aptos":
            return (0, serializer_2.deserializeAptosTransaction)(rawTransaction);
        case "crypto_org":
            return (0, serializer_6.deserializeCryptoOrgTransaction)(rawTransaction);
        case "ripple":
            return (0, serializer_11.deserializeRippleTransaction)(rawTransaction);
        case "celo":
            return (0, serializer_4.deserializeCeloTransaction)(rawTransaction);
        case "cosmos":
            return (0, serializer_5.deserializeCosmosTransaction)(rawTransaction);
        case "hedera":
            return (0, serializer_8.deserializeHederaTransaction)(rawTransaction);
        case "filecoin":
            return (0, serializer_9.deserializeFilecoinTransaction)(rawTransaction);
        case "tezos":
            return (0, serializer_13.deserializeTezosTransaction)(rawTransaction);
        case "polkadot":
            return (0, serializer_10.deserializePolkadotTransaction)(rawTransaction);
        case "stellar":
            return (0, serializer_12.deserializeStellarTransaction)(rawTransaction);
        case "ton":
            return (0, serializer_14.deserializeTonTransaction)(rawTransaction);
        case "tron":
            return (0, serializer_15.deserializeTronTransaction)(rawTransaction);
        case "near":
            return near.deserialize(rawTransaction);
        case "neo":
            return neo.deserialize(rawTransaction);
        case "elrond":
            return (0, serializer_16.deserializeElrondTransaction)(rawTransaction);
        case "cardano":
            return (0, serializer_17.deserializeCardanoTransaction)(rawTransaction);
        case "solana":
            return (0, serializer_18.deserializeSolanaTransaction)(rawTransaction);
        case "vechain":
            return (0, serializer_19.deserializeVechainTransaction)(rawTransaction);
        case "stacks":
            return (0, serializer_20.deserializeStacksTransaction)(rawTransaction);
        case "internet_computer":
            return (0, serializer_21.deserializeInternetComputerTransaction)(rawTransaction);
        case "casper":
            return (0, serializer_22.deserializeCasperTransaction)(rawTransaction);
        case "sui":
            return (0, serializer_23.deserializeSuiTransaction)(rawTransaction);
        default: {
            const exhaustiveCheck = rawTransaction; // https://www.typescriptlang.org/docs/handbook/2/narrowing.html#exhaustiveness-checking
            return exhaustiveCheck;
            // throw new Error("Can't deserialize transaction: family not supported");
        }
    }
}
exports.deserializeTransaction = deserializeTransaction;
//# sourceMappingURL=serializer.js.map