"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.schemaExchangeComplete = void 0;
const zod_1 = require("zod");
const families_1 = require("../../families");
const schemaFeeStrategyType = zod_1.z.enum(["SLOW", "MEDIUM", "FAST", "CUSTOM"]);
const schemaExchangeCompleteBaseParams = zod_1.z.object({
    provider: zod_1.z.string(),
    fromAccountId: zod_1.z.string(),
    rawTransaction: families_1.schemaRawTransaction,
    hexBinaryPayload: zod_1.z.string(),
    hexSignature: zod_1.z.string(),
    feeStrategy: schemaFeeStrategyType,
    tokenCurrency: zod_1.z.string().optional(),
});
const schemaExchangeCompleteFundParams = schemaExchangeCompleteBaseParams.extend({
    exchangeType: zod_1.z.literal("FUND"),
});
const schemaExchangeCompleteSellParams = schemaExchangeCompleteBaseParams.extend({
    exchangeType: zod_1.z.literal("SELL"),
});
const schemaExchangeCompleteSwapParams = schemaExchangeCompleteBaseParams.extend({
    exchangeType: zod_1.z.literal("SWAP"),
    toAccountId: zod_1.z.string(),
    swapId: zod_1.z.string(),
    rate: zod_1.z.number(),
});
const schemaExchangeCompleteParams = zod_1.z.discriminatedUnion("exchangeType", [
    schemaExchangeCompleteFundParams,
    schemaExchangeCompleteSellParams,
    schemaExchangeCompleteSwapParams,
]);
const schemaExchangeCompleteResults = zod_1.z.object({
    transactionHash: zod_1.z.string(),
});
exports.schemaExchangeComplete = {
    params: schemaExchangeCompleteParams,
    result: schemaExchangeCompleteResults,
};
//# sourceMappingURL=ExchangeComplete.js.map